<?php

	/*
	* Plugin Name: Ship From Address Modifier For UPS Label
	* Plugin URI: https://www.pluginhive.com/product/woocommerce-ups-shipping-plugin-with-print-label/
	* Description: This plugin will override Ship From Address as Billing Address in UPS Label while shipping to a different address.
	* Author: PluginHive
	* Author URI: https://pluginhive.com/
	* Version: 1.0
	* Text Domain: ph_ups_ship_from_address_modifier
	* Copyright: 2019 PluginHive.
	* WC requires at least: 3.0.0
	* WC tested up to: 3.7.0
	*/

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	if ( !class_exists( 'UPS_WooCommerce_Shipping' ) ) { 

		add_action( 'admin_init', 'ph_deactivate_ship_from_address_modifier_plugin' );

		if ( ! function_exists( 'ph_deactivate_ship_from_address_modifier_plugin' ) ) {
			function ph_deactivate_ship_from_address_modifier_plugin() {
				if ( !class_exists( 'UPS_WooCommerce_Shipping' ) ){
					deactivate_plugins( plugin_basename( __FILE__ ) );
					wp_safe_redirect( admin_url('plugins.php') );
				}
			}
		}
	}

	function ph_ups_ship_from_address_modifier_activation_check(){

		if ( !is_plugin_active('ups-woocommerce-shipping/ups-woocommerce-shipping.php') ){
			deactivate_plugins( basename( __FILE__ ) );
			wp_die( __("Oops! You tried installing the Ship From Address Modifier For UPS Label without activating UPS WooCommerce Shipping Plugin. Kindly activate <b>UPS WooCommerce Shipping Plugin</b> and then try again", "ph_prevent_ups_shiiping_to_po_box" ), "", array('back_link' => 1 ));
		}
	}

	register_activation_hook( __FILE__, 'ph_ups_ship_from_address_modifier_activation_check' );

	if( !class_exists('Ph_UPS_Ship_From_Address_Modifier') ){
		class Ph_UPS_Ship_From_Address_Modifier {

			public function __construct() {

				$this->id		= 'ph_ups_ship_from_address_modifier';

				add_action('woocommerce_checkout_update_order_meta', array( $this, 'ph_check_for_ship_to_different_address_status'), 12, 2);

				add_filter( 'wf_ups_shipment_confirm_request_data', array( $this, 'ph_change_ship_from_address_to_billing_address_in_label'), 12, 2 );

			}

			public function ph_check_for_ship_to_different_address_status($order_id, $post){

				$ship_to_different_address 	= ( is_array($post) && isset($post['ship_to_different_address']) && !empty($post['ship_to_different_address']) ) ? true : false;

				update_post_meta( $order_id, 'ph_ups_ship_to_different_address', $ship_to_different_address );
				

			}
			public function ph_change_ship_from_address_to_billing_address_in_label( $request, $order )
			{
				$order = wc_get_order($order);
				
				$ship_to_different_address = get_post_meta( $order->get_id(), 'ph_ups_ship_to_different_address', true );

				if( $ship_to_different_address )
				{

					if( is_a( $order, 'WC_Order') )
					{
						$billing_first_name 	= $order->get_billing_first_name();
						$billing_last_name 		= $order->get_billing_last_name();
						$billing_company 		= $order->get_billing_company();
						$billing_address_line1 	= $order->get_billing_address_1();
						$billing_address_line2 	= $order->get_billing_address_2();
						$billing_city 			= $order->get_billing_city();
						$billing_state			= $order->get_billing_state();
						$billing_postcode		= $order->get_billing_postcode();
						$billing_country		= $order->get_billing_country();
						$billing_email_id 		= $order->get_billing_email();
						$billing_phone_no 		= $order->get_billing_phone();

						$ups_settings 			= get_option( 'woocommerce_'.WF_UPS_ID.'_settings', null );
						$ups_shipper_number  	= isset( $ups_settings['shipper_number'] ) ? $ups_settings['shipper_number'] : '';
						$full_name				= htmlspecialchars($billing_first_name).' '.htmlspecialchars($billing_last_name);
						$company_name			= !empty($billing_company) ? htmlspecialchars($billing_company) : '-';
						$email_id				= !empty($billing_email_id) ? htmlspecialchars($billing_email_id) : '-';
						$phone_number			= ( strlen($billing_phone_no) > 15 ) ? str_replace(' ', '', $billing_phone_no) : ( ( strlen($billing_phone_no) < 10 ) ? '0000000000' :  $billing_phone_no );

						$countries_with_statecodes = array('US','CA','IE');
						$request['Shipment']['Shipper']	=	array(
							'Name'			=>	substr( $full_name, 0, 34 ),
							'AttentionName'	=>	substr( $company_name, 0, 34 ),
							'PhoneNumber'	=>	preg_replace( "/[^0-9]/", "", $phone_number ),
							'EMailAddress'	=>	$email_id,
							'ShipperNumber'	=>	$ups_shipper_number,
							'Address'		=>	array(
								'AddressLine1'	=> $billing_address_line1,
								'City'			=> $billing_city,
								'PostalCode'	=> $billing_postcode,
								'CountryCode'	=> $billing_country,
							),
						);

						// State Code valid for certain countries only
						if( in_array($billing_country, $countries_with_statecodes) )
						{ 
							$request['Shipment']['Shipper']['Address']['StateProvinceCode']	=	$billing_state;
						}
						
						if( isset($request['Shipment']['ReturnService']) && !empty($request['Shipment']['ReturnService']) )
						{
							$request['Shipment']['ShipTo']	=	array(
								'CompanyName'	=>	substr( $company_name, 0, 34 ),
								'AttentionName'	=>	substr( $full_name, 0, 34 ),
								'PhoneNumber'	=>	preg_replace( "/[^0-9]/", "", $phone_number ),
								'EMailAddress'	=>	$email_id,
								'Address'		=>	array(
									'AddressLine1'		=>	$billing_address_line1,
									'AddressLine2'		=>	!empty($billing_address_line2) ? $billing_address_line2 : '-',
									'City'				=>	$billing_city,
									'CountryCode'		=>	$billing_country,
									'PostalCode'		=>	$billing_postcode,
								)
							);

							if( in_array($billing_country, $countries_with_statecodes) )
							{ 
								$request['Shipment']['ShipTo']['Address']['StateProvinceCode']	=	$billing_state;
							}

						}else{
							$request['Shipment']['ShipFrom'] = array(
								'CompanyName'	=>	substr( $company_name, 0, 34 ),
								'AttentionName'	=>	substr( $full_name, 0, 34 ),
								'Address'		=>	array(
									'AddressLine1'	=>	$billing_address_line1,
									'City'			=>	$billing_city,
									'PostalCode'	=>	$billing_postcode,
									'CountryCode'	=>	$billing_country,
								),
							);

							if( in_array($billing_country, $countries_with_statecodes) )
							{ 
								$request['Shipment']['ShipFrom']['Address']['StateProvinceCode']	=	$billing_state;
							}
						}

					}
				}

				return $request;
			}


		}	

	}

	new Ph_UPS_Ship_From_Address_Modifier();